Responses to survey questions about advanced molecular diagnostic testing for infectious diseases presented to medical personnel who are members of EIN.
Usage
data(diagnoses)Format
diagnoses
A list with 3 objects that each have a length of 643.
waveA
numericvector that lists of the data collect period when the responses were collected during.q1A
charactervector that lists the responses to the types of advanced molecular diagnostic tests that have been ordered or used. This is an example of responses based on select that all apply data collection process. Possible values are Broad range 16S rRNA gene sequencing (Broadrange), Whole genome sequencing (Wholegenome), Metagenomic next-generation sequencing (MNGS), None of the above (None), and Other (Other), where the data values are listed within the parentheses. When multiple responses are present the data values are separated by"|".q2A
factorwith 5 levels for the responses to how often within the past two years advanced molecular diagnostic testing was performed. Possible values are Not at all, Once, Rarely (quarterly or less often), Sometimes (monthly), and Often (weekly). This is an example of where the responses collected come from the multiple choice question.